@@ -1,12 +1,13 @@
-from . import metrics, model, utils, visualization, pipeline
+from . import metrics, model, utils, visualization, pipeline, research_cv
 from .model.model_ import Model
 from .model.model_with_pipeline import ModelWithPipeline, ModelWithPipelineAndKfold
-from .metrics.metrics_ import multiclass_score, binary_score, gini, confusion_matrix, binary_score_, binary_scoreKfold
+from .metrics.metrics_ import multiclass_score, binary_score, gini, confusion_matrix, binary_score_, binary_scoreKfold, find_best_threshold
 from .pipeline.pipeline_ import MyPipeline, PipelineKfold
 from .data_processing.data_processing_ import Fillna, MinMaxScale, FillnaAndDropCatFeat, LabelEncoder, FeatureSelection, AssertGoodHeader
-from .visualization.plot import Plot, plot_importance_Kfold, plot_aucKfold
-from .utils.utils_ import params, params_prevent_overfit
-
+from .visualization.plot import Plot, plot_importance_Kfold, plot_aucKfold, __gini__, __giniKfold__
+from .visualization.plot import   __giniByUNiqueData__
+from .utils.utils_ import params, params_prevent_overfit, show_time
+from .research_cv.searchCv import SearchCv
 
 __all__ = ["data_processing",
            "metrics",
@@ -35,4 +36,10 @@ __all__ = ["data_processing",
            "plot_importance_Kfold",
            "plot_aucKfold",
            "params",
-           "params_prevent_overfit"]
\ No newline at end of file
+           "params_prevent_overfit",
+           "SearchCv",
+           "__gini__",
+           "__giniKfold__",
+           "__giniByUNiqueData__",
+           "show_time",
+           "find_best_threshold"]
\ No newline at end of file
