@@ -1,5 +1,5 @@
-from .utils_ import  print_time, extract_package_from_notebook,  memory_usage, _random_research_cv_, bayes_research_cv
-__all__ = ["print_time",
+from .utils_ import  show_time, extract_package_from_notebook,  memory_usage, _random_research_cv_, bayes_research_cv
+__all__ = ["show_time",
            "extract_package_from_notebook",
            "memory_usage",
            "_random_research_cv_",
